PhyMode

Enum PhyMode 

#[repr(u32)]
pub enum PhyMode { Lr = 0, _11b = 1, _11g = 2, _11a = 3, Ht20 = 4, Ht40 = 5, He20 = 6, Vht20 = 7, }
Available on crate features esp-now and unstable only.
Phy Mode

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Variants



Lr = 0

PHY mode for Low Rate



_11b = 1

PHY mode for 11b



_11g = 2

PHY mode for 11g



_11a = 3

PHY mode for 11a



Ht20 = 4

PHY mode for Bandwidth HT20



Ht40 = 5

PHY mode for Bandwidth HT40



He20 = 6

PHY mode for Bandwidth HE20



Vht20 = 7

PHY mode for Bandwidth VHT20